<!doctype html>
<html lang="en">
  <head>
    {% block head %}
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">

    <title>{{ album.title }}</title>
    <meta name="description" content="">
    <meta name="author" content="{{ album.author }}">
    <meta name="viewport" content="width=device-width">
    <link rel="stylesheet" href="{{ theme.url }}/css/style.min.css">
    {% if settings.use_assets_cdn %}
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=PT+Sans">
    <style>
      body { font: 100%/1.4 "PT Sans", sans-serif; }
      h1, h2, h3, h4, h5, h6 { font-family: "PT Sans", sans-serif; }
    </style>
    {% endif %}
    {% endblock %}
  </head>
  <body>
    <div class="container">
      <div class="four columns">
        <div class="sidebar">
          <h1><a href="{{ album.index_url }}">{{ index_title }}</a></h1>
          {% if settings.links %}
          <nav id="menu">
            <ul>
              {% for title, link in settings.links %}
              <li><a href="{{ link }}">{{ title }}</a></li>
              {% endfor %}
            </ul>
          </nav>
          {% endif %}
          <footer>
            <p>{% if album.author %}&copy; {{ album.author }} - {% endif %}
              Generated by <a href="{{ sigal_link }}">sigal</a></p>
          </footer>
        </div>
      </div>
      <div id="main" role="main" class="twelve columns offset-by-four">
        {% block content %}{% endblock %}
      </div>
    </div>

    {% block footer %}{% endblock %}
    {% include 'analytics.html' %}
    {% include 'piwik.html' %}
  </body>
</html>
